from setuptools import setup

setup(
    name='cast_from_env',
    version='0.0.5',
    description='Get and cast environment variables',
    author='Nic Wolff',
    author_email='nwolff@hearst.com',
    license='MIT',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url='http://github.com/Media-Platforms/cast-from-env',
    py_modules=['cast_from_env'],
)



from os import environ
from unittest import TestCase
from unittest.mock import patch

from cast_from_env import from_env


class XMLTests(TestCase):

    @patch.dict(environ, {'TEST_STR': 'a string', 'TEST_INT': '123', 'TEST_FLOAT': '12.34',
                          'TEST_TRUE': 'true', 'TEST_FALSE': 'no'})
    def test_from_env(self):
        assert from_env('NOT_SET') is None, 'Unset env var returns None if no default'
        assert from_env('NOT_SET', 'default') == 'default', 'Unset env var returns default'
        assert from_env('TEST_STR') == 'a string', 'Set env var with no default returns string'
        assert type(from_env('TEST_INT', 1)) is int, 'Env var with int default is cast to int'
        assert type(from_env('TEST_FLOAT', float)) is float, 'Env var is cast to float'
        assert from_env('TEST_TRUE', bool) is True, '"true" cast to bool is True'
        assert from_env('TEST_FALSE', True) is False, '"no" cast to bool is False'



from os import getenv


def from_env(name, default=None):
    """Get an environment variable's value and cast it to match the default, or a given type."""
    if type(default) is type:
        cast, default = default, None
    elif default is None:
        cast = str
    else:
        cast = type(default)
    value = getenv(name, default)
    if cast is bool:
        return value is not None and value.lower() in ('1', 't', 'true', 'y', 'yes', 'on')
    return None if value is None else cast(value)
